@@ -1,28 +1,30 @@
+#[cfg(RUSTC_WITH_SPECIALIZATION)]
+use solana_frozen_abi::abi_example::AbiExample;
 use {
-    crate::{
-        bank::{Builtin, Builtins},
-        system_instruction_processor,
+    crate::system_instruction_processor,
+    solana_program_runtime::{
+        invoke_context::{InvokeContext, ProcessInstructionWithContext},
+        stable_log,
     },
     solana_sdk::{
-        feature_set,
-        instruction::InstructionError,
-        process_instruction::{stable_log, InvokeContext, ProcessInstructionWithContext},
-        pubkey::Pubkey,
-        stake, system_program,
+        feature_set, instruction::InstructionError, pubkey::Pubkey, stake, system_program,
     },
+    std::fmt,
 };
 
 fn process_instruction_with_program_logging(
     process_instruction: ProcessInstructionWithContext,
-    program_id: &Pubkey,
+    first_instruction_account: usize,
     instruction_data: &[u8],
-    invoke_context: &mut dyn InvokeContext,
+    invoke_context: &mut InvokeContext,
 ) -> Result<(), InstructionError> {
-    let logger = invoke_context.get_logger();
+    let logger = invoke_context.get_log_collector();
+    let program_id = invoke_context.get_caller()?;
     stable_log::program_invoke(&logger, program_id, invoke_context.invoke_depth());
 
-    let result = process_instruction(program_id, instruction_data, invoke_context);
+    let result = process_instruction(first_instruction_account, instruction_data, invoke_context);
 
+    let program_id = invoke_context.get_caller()?;
     match &result {
         Ok(()) => stable_log::program_success(&logger, program_id),
         Err(err) => stable_log::program_failure(&logger, program_id, err),
@@ -32,10 +34,12 @@ fn process_instruction_with_program_logging(
 
 macro_rules! with_program_logging {
     ($process_instruction:expr) => {
-        |program_id: &Pubkey, instruction_data: &[u8], invoke_context: &mut dyn InvokeContext| {
+        |first_instruction_account: usize,
+         instruction_data: &[u8],
+         invoke_context: &mut InvokeContext| {
             process_instruction_with_program_logging(
                 $process_instruction,
-                program_id,
+                first_instruction_account,
                 instruction_data,
                 invoke_context,
             )
@@ -43,6 +47,60 @@ macro_rules! with_program_logging {
     };
 }
 
+#[derive(AbiExample, Debug, Clone)]
+pub enum ActivationType {
+    NewProgram,
+    NewVersion,
+    RemoveProgram,
+}
+
+#[derive(Clone)]
+pub struct Builtin {
+    pub name: String,
+    pub id: Pubkey,
+    pub process_instruction_with_context: ProcessInstructionWithContext,
+}
+
+impl Builtin {
+    pub fn new(
+        name: &str,
+        id: Pubkey,
+        process_instruction_with_context: ProcessInstructionWithContext,
+    ) -> Self {
+        Self {
+            name: name.to_string(),
+            id,
+            process_instruction_with_context,
+        }
+    }
+}
+
+impl fmt::Debug for Builtin {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        write!(f, "Builtin [name={}, id={}]", self.name, self.id)
+    }
+}
+
+#[cfg(RUSTC_WITH_SPECIALIZATION)]
+impl AbiExample for Builtin {
+    fn example() -> Self {
+        Self {
+            name: String::default(),
+            id: Pubkey::default(),
+            process_instruction_with_context: |_, _, _| Ok(()),
+        }
+    }
+}
+
+#[derive(Clone, Debug)]
+pub struct Builtins {
+    /// Builtin programs that are always available
+    pub genesis_builtins: Vec<Builtin>,
+
+    /// Builtin programs activated or deactivated dynamically by feature
+    pub feature_builtins: Vec<(Builtin, Pubkey, ActivationType)>,
+}
+
 /// Builtin programs that are always available
 fn genesis_builtins() -> Vec<Builtin> {
     vec![
@@ -69,15 +127,18 @@ fn genesis_builtins() -> Vec<Builtin> {
         Builtin::new(
             "secp256k1_program",
             solana_sdk::secp256k1_program::id(),
-            solana_secp256k1_program::process_instruction,
+            dummy_process_instruction,
         ),
     ]
 }
 
-#[derive(AbiExample, Debug, Clone)]
-pub enum ActivationType {
-    NewProgram,
-    NewVersion,
+/// place holder for secp256k1, remove when the precompile program is deactivated via feature activation
+fn dummy_process_instruction(
+    _first_instruction_account: usize,
+    _data: &[u8],
+    _invoke_context: &mut InvokeContext,
+) -> Result<(), InstructionError> {
+    Ok(())
 }
 
 /// Builtin programs activated dynamically by feature
@@ -99,14 +160,17 @@ fn feature_builtins() -> Vec<(Builtin, Pubkey, ActivationType)> {
             feature_set::add_compute_budget_program::id(),
             ActivationType::NewProgram,
         ),
+        // TODO when feature `prevent_calling_precompiles_as_programs` is
+        // cleaned up also remove "secp256k1_program" from the main builtins
+        // list
         (
             Builtin::new(
-                "ed25519_program",
-                solana_sdk::ed25519_program::id(),
-                solana_ed25519_program::process_instruction,
+                "secp256k1_program",
+                solana_sdk::secp256k1_program::id(),
+                dummy_process_instruction,
             ),
-            feature_set::ed25519_program_enabled::id(),
-            ActivationType::NewProgram,
+            feature_set::prevent_calling_precompiles_as_programs::id(),
+            ActivationType::RemoveProgram,
         ),
     ]
 }
