@@ -52,37 +52,57 @@ impl RentCollector {
         }
     }
 
+    /// true if it is easy to determine this account should consider having rent collected from it
+    pub fn should_collect_rent(
+        &self,
+        address: &Pubkey,
+        account: &impl ReadableAccount,
+        rent_for_sysvars: bool,
+    ) -> bool {
+        !(account.executable() // executable accounts must be rent-exempt balance
+            || (!rent_for_sysvars && sysvar::check_id(account.owner()))
+            || *address == incinerator::id())
+    }
+
+    /// given an account that 'should_collect_rent'
+    /// returns (amount rent due, is_exempt_from_rent)
+    pub fn get_rent_due(&self, account: &impl ReadableAccount) -> (u64, bool) {
+        let slots_elapsed: u64 = (account.rent_epoch()..=self.epoch)
+            .map(|epoch| self.epoch_schedule.get_slots_in_epoch(epoch + 1))
+            .sum();
+
+        // avoid infinite rent in rust 1.45
+        let years_elapsed = if self.slots_per_year != 0.0 {
+            slots_elapsed as f64 / self.slots_per_year
+        } else {
+            0.0
+        };
+
+        self.rent
+            .due(account.lamports(), account.data().len(), years_elapsed)
+    }
+
     // updates this account's lamports and status and returns
     //  the account rent collected, if any
-    //
+    // This is NOT thread safe at some level. If we try to collect from the same account in parallel, we may collect twice.
     #[must_use = "add to Bank::collected_rent"]
     pub fn collect_from_existing_account(
         &self,
         address: &Pubkey,
         account: &mut AccountSharedData,
         rent_for_sysvars: bool,
+        filler_account_suffix: Option<&Pubkey>,
     ) -> u64 {
-        if account.executable() // executable accounts must be rent-exempt balance
+        if !self.should_collect_rent(address, account, rent_for_sysvars)
             || account.rent_epoch() > self.epoch
-            || (!rent_for_sysvars && sysvar::check_id(account.owner()))
-            || *address == incinerator::id()
+            || crate::accounts_db::AccountsDb::is_filler_account_helper(
+                address,
+                filler_account_suffix,
+            )
         {
             0
         } else {
-            let slots_elapsed: u64 = (account.rent_epoch()..=self.epoch)
-                .map(|epoch| self.epoch_schedule.get_slots_in_epoch(epoch + 1))
-                .sum();
-
-            // avoid infinite rent in rust 1.45
-            let years_elapsed = if self.slots_per_year != 0.0 {
-                slots_elapsed as f64 / self.slots_per_year
-            } else {
-                0.0
-            };
-
-            let (rent_due, exempt) =
-                self.rent
-                    .due(account.lamports(), account.data().len(), years_elapsed);
+            let (rent_due, exempt) = self.get_rent_due(account);
 
             if exempt || rent_due != 0 {
                 if account.lamports() > rent_due {
@@ -120,7 +140,7 @@ impl RentCollector {
     ) -> u64 {
         // initialize rent_epoch as created at this epoch
         account.set_rent_epoch(self.epoch);
-        self.collect_from_existing_account(address, account, rent_for_sysvars)
+        self.collect_from_existing_account(address, account, rent_for_sysvars, None)
     }
 }
 
@@ -161,6 +181,7 @@ mod tests {
             &solana_sdk::pubkey::new_rand(),
             &mut existing_account,
             true,
+            None,
         );
         assert!(existing_account.lamports() < old_lamports);
         assert_eq!(existing_account.lamports() + collected, old_lamports);
@@ -187,7 +208,7 @@ mod tests {
         let rent_collector = RentCollector::default().clone_with_epoch(epoch);
 
         // first mark account as being collected while being rent-exempt
-        collected = rent_collector.collect_from_existing_account(&pubkey, &mut account, true);
+        collected = rent_collector.collect_from_existing_account(&pubkey, &mut account, true, None);
         assert_eq!(account.lamports(), huge_lamports);
         assert_eq!(collected, 0);
 
@@ -195,7 +216,7 @@ mod tests {
         account.set_lamports(tiny_lamports);
 
         // ... and trigger another rent collection on the same epoch and check that rent is working
-        collected = rent_collector.collect_from_existing_account(&pubkey, &mut account, true);
+        collected = rent_collector.collect_from_existing_account(&pubkey, &mut account, true, None);
         assert_eq!(account.lamports(), tiny_lamports - collected);
         assert_ne!(collected, 0);
     }
@@ -215,12 +236,14 @@ mod tests {
         let rent_collector = RentCollector::default().clone_with_epoch(epoch);
 
         // old behavior: sysvars are special-cased
-        let collected = rent_collector.collect_from_existing_account(&pubkey, &mut account, false);
+        let collected =
+            rent_collector.collect_from_existing_account(&pubkey, &mut account, false, None);
         assert_eq!(account.lamports(), tiny_lamports);
         assert_eq!(collected, 0);
 
         // new behavior: sysvars are NOT special-cased
-        let collected = rent_collector.collect_from_existing_account(&pubkey, &mut account, true);
+        let collected =
+            rent_collector.collect_from_existing_account(&pubkey, &mut account, true, None);
         assert_eq!(account.lamports(), 0);
         assert_eq!(collected, 1);
     }
