@@ -1,7 +1,11 @@
 //! Stakes serve as a cache of stake and vote accounts to derive
 //! node stakes
 use {
-    crate::vote_account::{VoteAccount, VoteAccounts, VoteAccountsHashMap},
+    crate::{
+        stake_delegations::StakeDelegations,
+        stake_history::StakeHistory,
+        vote_account::{VoteAccount, VoteAccounts, VoteAccountsHashMap},
+    },
     dashmap::DashMap,
     num_derive::ToPrimitive,
     num_traits::ToPrimitive,
@@ -17,7 +21,6 @@ use {
             self,
             state::{Delegation, StakeActivationStatus, StakeState},
         },
-        stake_history::StakeHistory,
     },
     solana_stake_program::stake_state,
     solana_vote_program::vote_state::VoteState,
@@ -120,7 +123,7 @@ pub struct Stakes {
     vote_accounts: VoteAccounts,
 
     /// stake_delegations
-    stake_delegations: HashMap<Pubkey, Delegation>,
+    stake_delegations: StakeDelegations,
 
     /// unused
     unused: u64,
@@ -204,35 +207,34 @@ impl Stakes {
         });
     }
 
-    // sum the stakes that point to the given voter_pubkey
+    /// Sum the stakes that point to the given voter_pubkey
     fn calculate_stake(
         &self,
         voter_pubkey: &Pubkey,
         epoch: Epoch,
-        stake_history: Option<&StakeHistory>,
+        stake_history: &StakeHistory,
     ) -> u64 {
+        let matches_voter_pubkey = |(_, stake_delegation): &(&_, &Delegation)| {
+            &stake_delegation.voter_pubkey == voter_pubkey
+        };
+        let get_stake = |(_, stake_delegation): (_, &Delegation)| {
+            stake_delegation.stake(epoch, Some(stake_history))
+        };
+
         self.stake_delegations
             .iter()
-            .map(|(_, stake_delegation)| {
-                if &stake_delegation.voter_pubkey == voter_pubkey {
-                    stake_delegation.stake(epoch, stake_history)
-                } else {
-                    0
-                }
-            })
+            .filter(matches_voter_pubkey)
+            .map(get_stake)
             .sum()
     }
 
+    /// Sum the lamports of the vote accounts and the delegated stake
     pub fn vote_balance_and_staked(&self) -> u64 {
-        self.stake_delegations
-            .iter()
-            .map(|(_, stake_delegation)| stake_delegation.stake)
-            .sum::<u64>()
-            + self
-                .vote_accounts
-                .iter()
-                .map(|(_pubkey, (_staked, vote_account))| vote_account.lamports())
-                .sum::<u64>()
+        let get_stake = |(_, stake_delegation): (_, &Delegation)| stake_delegation.stake;
+        let get_lamports = |(_, (_, vote_account)): (_, &(_, VoteAccount))| vote_account.lamports();
+
+        self.stake_delegations.iter().map(get_stake).sum::<u64>()
+            + self.vote_accounts.iter().map(get_lamports).sum::<u64>()
     }
 
     pub fn remove_vote_account(&mut self, vote_pubkey: &Pubkey) {
@@ -263,7 +265,7 @@ impl Stakes {
             if account.lamports() != 0 && VoteState::is_correct_size_and_initialized(account.data())
             {
                 let stake = old.as_ref().map_or_else(
-                    || self.calculate_stake(pubkey, self.epoch, Some(&self.stake_history)),
+                    || self.calculate_stake(pubkey, self.epoch, &self.stake_history),
                     |v| v.0,
                 );
 
@@ -331,7 +333,7 @@ impl Stakes {
         &self.vote_accounts
     }
 
-    pub fn stake_delegations(&self) -> &HashMap<Pubkey, Delegation> {
+    pub fn stake_delegations(&self) -> &StakeDelegations {
         &self.stake_delegations
     }
 
