@@ -52,8 +52,12 @@ pub struct VoteAccounts {
 }
 
 impl VoteAccount {
+    pub fn account(&self) -> &Account {
+        &self.0.account
+    }
+
     pub(crate) fn lamports(&self) -> u64 {
-        self.0.account.lamports
+        self.account().lamports
     }
 
     pub fn vote_state(&self) -> RwLockReadGuard<Result<VoteState, InstructionError>> {
@@ -198,6 +202,12 @@ impl From<Account> for VoteAccount {
     }
 }
 
+impl AsRef<VoteAccountInner> for VoteAccount {
+    fn as_ref(&self) -> &VoteAccountInner {
+        &self.0
+    }
+}
+
 impl From<AccountSharedData> for VoteAccountInner {
     fn from(account: AccountSharedData) -> Self {
         Self::from(Account::from(account))
